# sticker_tools

Код для конвертації наперед підготовлених файлів у формат .webm для стікерів
у телеграмі. Код налаштований на повільну, але якісну роботу, аби в доступні 255 кб
вмістити якомога більше даних з меншою кільістю артефактів від стиснення.

Програма також автоматично редагує метадані в конвертованому стікері аби обійти ліміт
телеграму в 3 секунди. Ви можете завантажувати стікери з будь-якою тривалістю, якщо
їх розмір не перевищує 255 кб (але я не рекомендую більше 20 секунд).

Програма доступна через CLI і GUI.

## CLI
### Встановлення
1. Встановіть `ffmpeg`

   На Linux: 
```bash
  sudo apt install ffmpeg
```

   На MacOs: 
```zsh
  brew install ffmpeg
```

   На Windows: Розбирайтеся самі, легше просто завантажити 
   і запустити GUI (див. нижче)

2. Встановіть `Python >= 3.12`
3. Встановіть `sticker_tools` з PyPi за допомого команди
   ```bash
   python3 -m pip install sticker-tools
   ```
   
### Використання
Пакет `sticker-tools` додає всього одну команду - `sticker`.
Першим і єдиним аргументом повинен бути шлях до файла який потрімно обробити.
1. Якщо формат файла - .webm - програма просто відредагує метадані аби зменшити
формальну тривалість стікера до 1 секунди.
2. Якщо формат файла інший (.mp4, .mov, .avi або .mkv) - програма спочатку конвертує
файл в .webm, а тоді пропатчить тривалість.

Шаблон команди:
```bash
   sticker path/to/your/file
```

## GUI
Для Windows існує інтуітивна GUI версія програми, яка включає
усі необхідні залежності. Просто завантажте і запустіть. Скомпільована
версія також включає інструкцію з використання.

Скомпільовані .exe файли будуть публікуватися в розділі релізів.


